// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

********************************************************************************
*******     BEGIN DATA MANIPULATION OF CHAPTER 3b SIX-OCCASION EXAMPLE   *******
*******               CHANGE "filesave" to your directory                *******
********************************************************************************

// Defining global variable for file location to be replaced in code below
   global filesave "C:\Dropbox\22_PSQF6271\PSQF6271_Example3b"

// Import chapter 3 six-occasion stacked data
   use "$filesave\STATA_Chapter3b.dta", clear
   
// Sort by person and session
   sort personid session

********************************************************************************
*******               BEGIN CHAPTER 3b SIX-OCCASION MODELS               *******
********************************************************************************

// Open external text file to save results to
   log using $filesave\STATA_Chapter3b_Output.log, replace name(STATA_Chapter3b)

display "Chapter 3b Example: Means by session for RT outcome"
tabulate session, summarize(rt)

display "Eq 3.10: Between-Person Independent ANOVA via STATA MIXED"
mixed rt ib(last).session,                          ///
           || personid: , noconstant variance reml  ///
           residuals(independent,t(session)) dfmethod(residual) dftable(pvalue)
      display "-2LL = " e(ll)*-2  // Print -2LL for model  
      estat ic, n(101)            // Information criteria using level-2 N
      contrast i.session, small   // Omnibus F-test for mean diffs
      margins  i.session          // Means per session  
	  margins  i.session, pwcompare(pveffects) df(600) // Mean differences
      estimates store FitBP       // Save -2LL for LRT

display "Eq 3.10: Univariate Repeated Measures ANOVA via STATA MIXED"
mixed rt ib(last).session,                          ///
           || personid: , noconstant variance reml  ///
           residuals(exchangeable,t(session)) dfmethod(satterthwaite) dftable(pvalue)
      display "-2LL = " e(ll)*-2      // Print -2LL for model  
      estat ic, n(101)                // Information criteria using level-2 N
      estat wcorrelation, covariance  // RCOV matrix
      estat wcorrelation              // RCORR matrix
      contrast i.session, small       // Omnibus F-test for mean diffs
      margins  i.session              // Means per session   
	  margins  i.session, pwcompare(pveffects) df(500) // Mean differences
      estimates store FitUWP          // Save -2LL for LRT
      lrtest FitUWP FitBP             // LRT model comparison (more, fewer)

display "Eq 3.10: Multivariate Repeated Measures ANOVA via STATA MIXED"
mixed rt ib(last).session,                          ///
           || personid: , noconstant variance reml  ///
           residuals(unstructured,t(session)) dfmethod(satterthwaite) dftable(pvalue)
      display "-2LL = " e(ll)*-2          // Print -2LL for model  
      estat ic, n(101),                   // Information criteria using level-2 N
      estat wcorrelation, covariance      // RCOV matrix
      estat wcorrelation                  // RCORR matrix
      contrast i.session, small           // Omnibus F-test for mean diffs
      margins  i.session                  // Means per session 
	  margins  i.session, pwcompare(pveffects) df(100) // Mean differences
      estimates store FitMWP              // Save -2LL for LRT
      lrtest FitMWP FitUWP                // LRT model comparison (more, fewer)

 
****** END CHAPTER 3b MODELS ******

// Close external text file of saved results
   log close STATA_Chapter3b

